##  Automation 2: Relation Is Removed (Business Context from Child)
Automation Configuration Parameter | Configuration
---|---
Trigger (When) |
  * Fact Sheet Type: Application
  * Event: Relation is removed
  * Fact Sheet Relation: Business contexts


Conditions (If) | Configure optional conditions for the automation.
Actions (Then) | Run Script: Use the same script as in [automation 1](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD#loio2ad6775d50c442168a6dd398192dab72__automation-1).


